@@ -1,11 +1,13 @@
-from juriscraper.lib.html_utils import get_row_column_links
-from juriscraper.lib.html_utils import get_row_column_text
+from juriscraper.lib.html_utils import (
+    get_row_column_links,
+    get_row_column_text,
+)
 from juriscraper.OpinionSiteLinear import OpinionSiteLinear
 
 
 class Site(OpinionSiteLinear):
     def __init__(self, *args, **kwargs):
-        super(Site, self).__init__(*args, **kwargs)
+        super().__init__(*args, **kwargs)
         self.court_id = self.__module__
         self.url = "https://appellate-records.courts.alaska.gov/CMSPublic/Home/Opinions?isCOA=False"
         self.status = "Published"
