@@ -7,7 +7,7 @@ from . import fladistctapp_1_per_curiam
 
 class Site(fladistctapp_1_per_curiam.Site):
     def __init__(self, *args, **kwargs):
-        super(Site, self).__init__(*args, **kwargs)
+        super().__init__(*args, **kwargs)
         self.court_id = self.__module__
         self.type_id = 1  # Written
         self.url = self.get_url()
