@@ -7,7 +7,7 @@ from juriscraper.opinions.united_states.state import nyappdiv_1st
 
 class Site(nyappdiv_1st.Site):
     def __init__(self, *args, **kwargs):
-        super(Site, self).__init__(*args, **kwargs)
+        super().__init__(*args, **kwargs)
         self.court_id = self.__module__
         self.division = 3
         self.url = self.build_url()
