@@ -11,7 +11,7 @@ from juriscraper.opinions.united_states.state import ri_p
 
 class Site(ri_p.Site):
     def __init__(self, *args, **kwargs):
-        super(Site, self).__init__(*args, **kwargs)
+        super().__init__(*args, **kwargs)
         self.court_id = self.__module__
         self.include_summary = False
         self.status = "Unpublished"
